InverseInDegreeEdgeWeighting
============================

.. currentmodule:: pykeen.nn.weighting

.. autoclass:: InverseInDegreeEdgeWeighting
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~InverseInDegreeEdgeWeighting.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
